﻿using Infragistics.Win;
using Infragistics.Win.FormattedLinkLabel;
using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace UltraGridFormattedCaption
{

    public class FormattedCaptionCreationFilter : IUIElementCreationFilter
    {
        public void AfterCreateChildElements(UIElement parent)
        {
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            if (parent is CaptionAreaUIElement)
            {
                // Reuse the existing FormattedTextUIElement if there's already one there
                FormattedTextUIElement childElement = parent.ChildElements.OfType<FormattedTextUIElement>().FirstOrDefault();

                if (childElement == null)
                {
                    childElement = new FormattedTextUIElement(parent);
                    parent.ChildElements.Add(childElement);
                }

                // In order to customize the formatted text that appears in the caption, modify this statement
                string formattedText = "<p align = \"center\">" + parent.Control.Text + "</p>";

                childElement.Value = ParsedFormattedTextValue.Parse(formattedText, ParsedFormattedTextValue.ValueType.AutoDetect, out Exception ex);
                childElement.Rect = parent.RectInsideBorders;
                return true;
            }
            else if (parent is GroupByRowDescriptionUIElement)
            {
                // Reuse the existing FormattedTextUIElement if there's already one there
                FormattedTextUIElement childElement = parent.ChildElements.OfType<FormattedTextUIElement>().FirstOrDefault();

                if (childElement == null)
                {
                    childElement = new FormattedTextUIElement(parent);
                    parent.ChildElements.Add(childElement);
                }

                var groupByRow = parent.GetContext(typeof(UltraGridGroupByRow)) as UltraGridGroupByRow;
                // In order to customize the formatted text that appears in the caption, modify this statement
                string formattedText = groupByRow.Description;

                childElement.Value = ParsedFormattedTextValue.Parse(formattedText, ParsedFormattedTextValue.ValueType.AutoDetect, out Exception ex);
                childElement.Rect = parent.RectInsideBorders;
                return true;
            }
            return false;
        }
    }
}
